@@ -101,14 +101,13 @@ class GoogleTests(OAuth2TestsMixin, TestCase):
             "exp": time.time() - 1,
             "aud": "foo",
         }
+        template_ext = getattr(settings, "ACCOUNT_TEMPLATE_EXTENSION", "html")
         for key, value in wrong_claim_values.items():
             with self.subTest(key):
                 self.identity_overwrites = {key: value}
                 resp = self.login(resp_mock=None)
                 self.assertTemplateUsed(
-                    resp,
-                    "socialaccount/authentication_error.%s"
-                    % getattr(settings, "ACCOUNT_TEMPLATE_EXTENSION", "html"),
+                    resp, f"socialaccount/authentication_error.{template_ext}"
                 )
 
     def test_username_based_on_email(self):
@@ -139,6 +138,7 @@ class GoogleTests(OAuth2TestsMixin, TestCase):
         user_signed_up.connect(on_signed_up)
         self.login(resp_mock=None)
         self.assertTrue(len(sent_signals) > 0)
+        user_signed_up.disconnect(on_signed_up)
 
     @override_settings(ACCOUNT_EMAIL_CONFIRMATION_HMAC=False)
     def test_email_unverified(self):
