@@ -1,3 +1,5 @@
+from http import HTTPStatus
+
 from django.test import TestCase
 
 from allauth.socialaccount.providers.mediawiki.provider import MediaWikiProvider
@@ -10,7 +12,7 @@ class MediaWikiTests(OAuth2TestsMixin, TestCase):
 
     def get_mocked_response(self):
         return MockedResponse(
-            200,
+            HTTPStatus.OK,
             """
                 {
                     "iss": "https://meta.wikimedia.org",
