@@ -78,7 +78,7 @@ class TwitchTests(OAuth2TestsMixin, TestCase):
         they are caught and rendered to generic error HTML
         """
         request = RequestFactory().get(
-            reverse(self.provider.id + "_login"),
+            reverse(f"{self.provider.id}_login"),
             {"process": "login"},
         )
         adapter = TwitchOAuth2Adapter(request)
