@@ -46,7 +46,7 @@ class YNABTests(OAuth2TestsMixin, TestCase):
                     raise HTTPError(None)
 
         request = RequestFactory().get(
-            reverse(self.provider.id + "_login"), dict(process="login")
+            reverse(f"{self.provider.id}_login"), dict(process="login")
         )
 
         adapter = YNABOAuth2Adapter(request)
